.. _many ways:

***********************
Many Ways to Contribute
***********************

While this |contributor guide| primarily describes the process of contributing code,
documentation, and tests to PlasmaPy, there are many ways to contribute
to an open source project! Some of the possibilities are:

* |:computer:| Contribute new code, documentation, and tests.
* |:recycle:| Refactor existing code and tests.
* |:memo:| Improve the description of plasma physics in |PlasmaPy's documentation|.
* |:books:| Write educational |Jupyter| notebook that introduce plasma concepts
  using PlasmaPy.
* |:movie_camera:| Create videos that show how to use PlasmaPy.
* |:white_check_mark:| Participate in code reviews.
* |:clipboard:| Help with project management.
* |:bulb:| `Request new features`_.
* |:lady_beetle:| `Report bugs`_.
* |:globe_with_meridians:| Improve |PlasmaPy's website|.
* |:calendar_spiral:| Help organize events such as |Plasma Hack Week| or the `PlasmaPy
  Summer School`_.
* |:speech_balloon:| Provide feedback on how existing functionality could be improved.
* |:motorway:| Help update PlasmaPy's development roadmap. ️
* |:busts_in_silhouette:| Be part of the PlasmaPy community!

.. tip::

   To learn more, please check out this community guide on `How to
   Contribute to Open Source`_.

.. _How to Contribute to Open Source: https://opensource.guide/how-to-contribute
.. _PlasmaPy Summer School: https://www.plasmapy.org/meetings/summer-school-2024
.. _report bugs: https://github.com/PlasmaPy/PlasmaPy/issues/new?assignees=&labels=Bug&template=bug_report.yml
.. _request new features: https://github.com/PlasmaPy/PlasmaPy/issues/new?assignees=&labels=Feature+request&template=feature_request.yml
